@@ -297,7 +297,7 @@ Result FuelClient::ModelDetails(const ModelIdentifier &_id,
 Result FuelClient::ModelDetails(const ModelIdentifier &_id,
     ModelIdentifier &_model, const std::vector<std::string> &_headers) const
 {
-  ignition::fuel_tools::Rest rest;
+  Rest rest;
   RestResponse resp;
 
   auto serverUrl = _id.Server().Url().Str();
@@ -361,7 +361,7 @@ Result FuelClient::WorldDetails(const WorldIdentifier &_id,
   if (serverUrl.empty() || _id.Owner().empty() || _id.Name().empty())
     return Result(ResultType::FETCH_ERROR);
 
-  ignition::fuel_tools::Rest rest;
+  Rest rest;
   RestResponse resp;
 
   auto version = _id.Server().Version();
@@ -483,7 +483,7 @@ Result FuelClient::UploadModel(const std::string &_pathToModelDir,
     const ModelIdentifier &_id, const std::vector<std::string> &_headers,
     bool _private, const std::string &_owner)
 {
-  ignition::fuel_tools::Rest rest;
+  Rest rest;
   RestResponse resp;
 
   std::multimap<std::string, std::string> form;
@@ -539,7 +539,7 @@ Result FuelClient::DeleteModel(const ModelIdentifier &)
 }
 
 void FuelClient::AddServerConfigParametersToHeaders(
-  const ignition::fuel_tools::ServerConfig &_serverConfig,
+  const ServerConfig &_serverConfig,
   std::vector<std::string> &_headers) const
 {
   bool privateTokenDefined = false;
@@ -563,7 +563,7 @@ void FuelClient::AddServerConfigParametersToHeaders(
 Result FuelClient::DeleteUrl(const ignition::common::URI &_uri,
     const std::vector<std::string> &_headers)
 {
-  ignition::fuel_tools::Rest rest;
+  Rest rest;
   RestResponse resp;
 
   std::string server;
@@ -638,12 +638,16 @@ Result FuelClient::DownloadModel(const ModelIdentifier &_id,
   if(!res)
     return res;
 
-  for (auto dep : dependencies)
+  for (ModelIdentifier dep : dependencies)
   {
-    auto dep_res = this->DownloadModel(dep, _headers);
+    // Download dependency if not in the local cache
+    if (!this->dataPtr->cache->MatchingModel(dep))
+    {
+      auto dep_res = this->DownloadModel(dep, _headers);
 
-    if(!dep_res)
-      return dep_res;
+      if(!dep_res)
+        return dep_res;
+    }
   }
 
   return res;
@@ -673,7 +677,7 @@ Result FuelClient::DownloadModel(const ModelIdentifier &_id,
   AddServerConfigParametersToHeaders(
     _id.Server(), headersIncludingServerConfig);
   // Request
-  ignition::fuel_tools::Rest rest;
+  Rest rest;
   RestResponse resp;
   resp = rest.Request(HttpMethod::GET, _id.Server().Url().Str(),
       _id.Server().Version(), route.Str(), {},
@@ -726,16 +730,16 @@ Result FuelClient::ModelDependencies(const ModelIdentifier &_id,
 
   // Locate any dependencies from the input model and download them.
   std::string path;
-  ignition::msgs::FuelMetadata meta;
-  if (this->CachedModel(ignition::common::URI(_id.UniqueName()), path))
+  msgs::FuelMetadata meta;
+  if (this->CachedModel(common::URI(_id.UniqueName()), path))
   {
     std::string metadataPath =
-      ignition::common::joinPaths(path, "metadata.pbtxt");
+      common::joinPaths(path, "metadata.pbtxt");
     std::string modelConfigPath =
-      ignition::common::joinPaths(path, "model.config");
+      common::joinPaths(path, "model.config");
 
-    bool foundMetadataPath = ignition::common::exists(metadataPath);
-    bool foundModelConfigPath = ignition::common::exists(modelConfigPath);
+    bool foundMetadataPath = common::exists(metadataPath);
+    bool foundModelConfigPath = common::exists(modelConfigPath);
 
     if (foundMetadataPath || foundModelConfigPath)
     {
@@ -754,7 +758,7 @@ Result FuelClient::ModelDependencies(const ModelIdentifier &_id,
       }
       else
       {
-        if (!ignition::msgs::ConvertFuelMetadata(inputStr, meta))
+        if (!msgs::ConvertFuelMetadata(inputStr, meta))
         {
           return Result(ResultType::UPLOAD_ERROR);
         }
@@ -762,7 +766,7 @@ Result FuelClient::ModelDependencies(const ModelIdentifier &_id,
 
       for (int i = 0; i < meta.dependencies_size(); ++i)
       {
-        ignition::common::URI dependencyURI(meta.dependencies(i).uri());
+        common::URI dependencyURI(meta.dependencies(i).uri());
 
         ModelIdentifier dependencyID;
         if(!this->ParseModelUrl(dependencyURI, dependencyID))
@@ -847,7 +851,7 @@ Result FuelClient::DownloadWorld(WorldIdentifier &_id,
     _id.Server(), headersIncludingServerConfig);
 
   // Request
-  ignition::fuel_tools::Rest rest;
+  Rest rest;
   RestResponse resp;
   resp = rest.Request(HttpMethod::GET, _id.Server().Url().Str(),
       _id.Server().Version(), route.Str(), {},
@@ -997,7 +1001,7 @@ std::vector<FuelClient::ModelResult> FuelClient::DownloadModels(
 Result FuelClient::DownloadWorlds(
     const std::vector<WorldIdentifier> &_ids, size_t _jobs)
 {
-  std::deque<std::future<ignition::fuel_tools::Result>> tasks;
+  std::deque<std::future<Result>> tasks;
   // Check for finished tasks by checking if the status of their futures is
   // "ready". If a task is finished, check if it succeeded and print out an
   // error message if it failed. When a task is finished, it gets erased from
@@ -1020,7 +1024,7 @@ Result FuelClient::DownloadWorlds(
     {
       for (auto taskIt = finishedIt; taskIt != tasks.end(); ++taskIt)
       {
-        ignition::fuel_tools::Result result = taskIt->get();
+        Result result = taskIt->get();
         if (result)
         {
           ++itemCount;
@@ -1423,7 +1427,7 @@ Result FuelClient::DownloadModel(const common::URI &_modelUrl,
     id.SetVersion(model.Identification().Version());
   }
 
-  _path = ignition::common::joinPaths(this->Config().CacheLocation(),
+  _path = common::joinPaths(this->Config().CacheLocation(),
       id.Server().Url().Path().Str(), id.Owner(), "models", id.Name(),
       id.VersionStr());
 
@@ -1543,10 +1547,10 @@ Result FuelClient::CachedModelFile(const common::URI &_fileUrl,
   // Check if file exists
   filePath = common::joinPaths(modelPath, filePath);
 
-  std::vector<std::string> tokens = ignition::common::split(filePath, "/");
+  std::vector<std::string> tokens = common::split(filePath, "/");
   std::string sTemp;
   for (auto s : tokens)
-    sTemp = ignition::common::joinPaths(sTemp, s);
+    sTemp = common::joinPaths(sTemp, s);
   filePath = sTemp;
 
   if (common::exists(filePath))
@@ -1593,7 +1597,7 @@ Result FuelClient::CachedWorldFile(const common::URI &_fileUrl,
 
 //////////////////////////////////////////////////
 Result FuelClient::PatchModel(
-    const ignition::fuel_tools::ModelIdentifier &_model,
+    const ModelIdentifier &_model,
     const std::vector<std::string> &_headers)
 {
   return this->PatchModel(_model, _headers, "");
@@ -1601,11 +1605,11 @@ Result FuelClient::PatchModel(
 
 //////////////////////////////////////////////////
 Result FuelClient::PatchModel(
-    const ignition::fuel_tools::ModelIdentifier &_model,
+    const ModelIdentifier &_model,
     const std::vector<std::string> &_headers,
     const std::string &_pathToModelDir)
 {
-  ignition::fuel_tools::Rest rest;
+  Rest rest;
   RestResponse resp;
 
   auto serverUrl = _model.Server().Url().Str();
@@ -1672,7 +1676,7 @@ bool FuelClientPrivate::FillModelForm(const std::string &_pathToModelDir,
     return false;
   }
 
-  ignition::msgs::FuelMetadata meta;
+  msgs::FuelMetadata meta;
 
   // Try the `metadata.pbtxt` file first since it contains more information
   // than `model.config`.
@@ -1700,7 +1704,7 @@ bool FuelClientPrivate::FillModelForm(const std::string &_pathToModelDir,
     std::string inputStr((std::istreambuf_iterator<char>(inputFile)),
         std::istreambuf_iterator<char>());
 
-    if (!ignition::msgs::ConvertFuelMetadata(inputStr, meta))
+    if (!msgs::ConvertFuelMetadata(inputStr, meta))
     {
       ignerr << "Unable to convert model config[" << _pathToModelDir << "].\n";
       return false;
