@@ -89,7 +89,7 @@ void createLocalModel(ClientConfig &_conf)
         "model.dae")));
   }
 
-  ignition::fuel_tools::ServerConfig srv;
+  ServerConfig srv;
   srv.SetUrl(common::URI("http://localhost:8007/"));
   _conf.AddServer(srv);
 }
@@ -120,8 +120,8 @@ void createLocalWorld(ClientConfig &_conf)
         "strawberry.world")));
   }
 
-  ignition::fuel_tools::ServerConfig srv;
-  srv.SetUrl(ignition::common::URI("http://localhost:8007/"));
+  ServerConfig srv;
+  srv.SetUrl(common::URI("http://localhost:8007/"));
   _conf.AddServer(srv);
 }
 
@@ -130,7 +130,7 @@ class FuelClientTest : public ::testing::Test
 {
   public: void SetUp() override
   {
-    ignition::common::Console::SetVerbosity(4);
+    common::Console::SetVerbosity(4);
   }
 };
 
@@ -146,7 +146,7 @@ TEST_F(FuelClientTest, ParseModelURL)
     ModelIdentifier id;
     const std::string url{
       "https://some.example.org/1.0/german/models/Cardboard Box"};
-    EXPECT_TRUE(client.ParseModelUrl(ignition::common::URI(url), id));
+    EXPECT_TRUE(client.ParseModelUrl(common::URI(url), id));
 
     EXPECT_EQ(id.Server().Url().Str(), "https://some.example.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
@@ -165,7 +165,7 @@ TEST_F(FuelClientTest, ParseModelURL)
     ModelIdentifier id;
     const std::string url{
       "https://fuel.ignitionrobotics.org/1.0/german/models/Cardboard Box/4"};
-    EXPECT_TRUE(client.ParseModelUrl(ignition::common::URI(url), id));
+    EXPECT_TRUE(client.ParseModelUrl(common::URI(url), id));
 
     EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
@@ -185,7 +185,7 @@ TEST_F(FuelClientTest, ParseModelURL)
     ModelIdentifier id;
     const std::string url{
       "https://fuel.ignitionrobotics.org/5.0/german/models/Cardboard Box/6/"};
-    EXPECT_TRUE(client.ParseModelUrl(ignition::common::URI(url), id));
+    EXPECT_TRUE(client.ParseModelUrl(common::URI(url), id));
 
     EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
@@ -202,7 +202,7 @@ TEST_F(FuelClientTest, ParseModelURL)
     ModelIdentifier id;
     const std::string url{
       "https://fuel.ignitionrobotics.org/german/models/Cardboard Box"};
-    EXPECT_TRUE(client.ParseModelUrl(ignition::common::URI(url), id));
+    EXPECT_TRUE(client.ParseModelUrl(common::URI(url), id));
 
     EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_FALSE(id.Server().Version().empty());
@@ -221,7 +221,7 @@ TEST_F(FuelClientTest, ParseModelURL)
     ModelIdentifier id;
     const std::string url{
       "https://fuel.ignitionrobotics.org/german/models/Cardboard Box/tip"};
-    EXPECT_TRUE(client.ParseModelUrl(ignition::common::URI(url), id));
+    EXPECT_TRUE(client.ParseModelUrl(common::URI(url), id));
 
     EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
@@ -234,7 +234,7 @@ TEST_F(FuelClientTest, ParseModelURL)
   {
     FuelClient client;
     ModelIdentifier id;
-    EXPECT_FALSE(client.ParseModelUrl(ignition::common::URI("http://bad.url"),
+    EXPECT_FALSE(client.ParseModelUrl(common::URI("http://bad.url"),
           id));
   }
 
@@ -242,13 +242,13 @@ TEST_F(FuelClientTest, ParseModelURL)
   {
     FuelClient client;
     ModelIdentifier id;
-    EXPECT_FALSE(client.ParseModelUrl(ignition::common::URI("bad url"),
+    EXPECT_FALSE(client.ParseModelUrl(common::URI("bad url"),
           id));
   }
   {
     FuelClient client;
     ModelIdentifier id;
-    EXPECT_FALSE(client.ParseModelUrl(ignition::common::URI("ba://url"),
+    EXPECT_FALSE(client.ParseModelUrl(common::URI("ba://url"),
           id));
   }
   {
@@ -256,21 +256,21 @@ TEST_F(FuelClientTest, ParseModelURL)
     ModelIdentifier id;
     const std::string url{
       "https://fuel.ignitionrobotics.org/german/models/Cardboard Box/banana"};
-    EXPECT_FALSE(client.ParseModelUrl(ignition::common::URI(url), id));
+    EXPECT_FALSE(client.ParseModelUrl(common::URI(url), id));
   }
   {
     FuelClient client;
     ModelIdentifier id;
     const std::string url{
       "https://fuel.ignitionrobotics.org/banana/german/models/Cardboard Box"};
-    EXPECT_FALSE(client.ParseModelUrl(ignition::common::URI(url), id));
+    EXPECT_FALSE(client.ParseModelUrl(common::URI(url), id));
   }
   {
     FuelClient client;
     ModelIdentifier id;
     const std::string url{
       "https://fuel.ignitionrobotics.org/99/german/models/Cardboard Box"};
-    EXPECT_FALSE(client.ParseModelUrl(ignition::common::URI(url), id));
+    EXPECT_FALSE(client.ParseModelUrl(common::URI(url), id));
   }
   {
     FuelClient client;
@@ -278,7 +278,7 @@ TEST_F(FuelClientTest, ParseModelURL)
     const std::string url{
       "https://fuel.ignitionrobotics.org/2/2/german/models"
         "/Cardboard Box/banana"};
-    EXPECT_FALSE(client.ParseModelUrl(ignition::common::URI(url), id));
+    EXPECT_FALSE(client.ParseModelUrl(common::URI(url), id));
   }
 }
 
@@ -539,12 +539,14 @@ TEST_F(FuelClientTest, DownloadModel)
     EXPECT_EQ(ResultType::FETCH_ALREADY_EXISTS, res5.Type());
   }
 
-  // Download model with a dependency specified within its `model.config`
+  // Download model with a dependency specified within its `model.config`.
+  // The dependency points to fuel.gazebosim.org.
   {
     common::URI url{
-        "https://fuel.ignitionrobotics.org/1.0/JShep1/models/hatchback_red_2"};
+      "https://fuel.ignitionrobotics.org/1.0/openrobotics/models/hatchback red"
+    };
     common::URI depUrl{
-        "https://fuel.ignitionrobotics.org/1.0/JShep1/models/hatchback_2"};
+      "https://fuel.gazebosim.org/1.0/openrobotics/models/hatchback"};
 
     // Check it is not cached
     std::string cachedPath;
@@ -672,7 +674,8 @@ TEST_F(FuelClientTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(ModelDependencies))
 /////////////////////////////////////////////////
 // Windows doesn't support colons in filenames
 // https://github.com/ignitionrobotics/ign-fuel-tools/issues/106
-TEST_F(FuelClientTest, CachedModel)
+// See https://github.com/gazebosim/gz-fuel-tools/issues/231
+TEST_F(FuelClientTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(CachedModel))
 {
   // Configure to use binary path as cache and populate it
   ASSERT_EQ(0, ChangeDirectory(PROJECT_BINARY_PATH));
@@ -1071,7 +1074,7 @@ TEST_F(FuelClientTest, DownloadWorld)
   ASSERT_TRUE(common::createDirectories("test_cache"));
 
   ServerConfig server;
-  server.SetUrl(ignition::common::URI(
+  server.SetUrl(common::URI(
         "https://fuel.ignitionrobotics.org"));
 
   ClientConfig config;
