@@ -28,23 +28,25 @@
 #include <regex>
 #include <string>
 #include <vector>
-#include <gz/common/Console.hh>
-#include <gz/common/Filesystem.hh>
-#include <gz/common/StringUtils.hh>
-#include <gz/common/Util.hh>
-#include <gz/math/SemanticVersion.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Filesystem.hh>
+#include <ignition/common/StringUtils.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/math/SemanticVersion.hh>
 
-#include "gz/fuel_tools/ClientConfig.hh"
-#include "gz/fuel_tools/LocalCache.hh"
-#include "gz/fuel_tools/ModelIterPrivate.hh"
-#include "gz/fuel_tools/ModelPrivate.hh"
-#include "gz/fuel_tools/Zip.hh"
-#include "gz/fuel_tools/WorldIterPrivate.hh"
+#include "ignition/fuel_tools/ClientConfig.hh"
+#include "ignition/fuel_tools/Helpers.hh"
+#include "ignition/fuel_tools/LocalCache.hh"
+#include "ignition/fuel_tools/Zip.hh"
+
+#include "ModelPrivate.hh"
+#include "ModelIterPrivate.hh"
+#include "WorldIterPrivate.hh"
 
 using namespace ignition;
 using namespace fuel_tools;
 
-class gz::fuel_tools::LocalCachePrivate
+class ignition::fuel_tools::LocalCachePrivate
 {
   /// \brief return all models in a given directory
   /// \param[in] _path A directory for the local server cache
@@ -228,7 +230,8 @@ ModelIter LocalCache::AllModels()
     for (auto &server : this->dataPtr->config->Servers())
     {
       std::string path = common::joinPaths(
-          this->dataPtr->config->CacheLocation(), server.Url().Path().Str());
+          this->dataPtr->config->CacheLocation(), uriToPath(server.Url()));
+
       auto srvModels = this->dataPtr->ModelsInServer(path);
       for (auto &mod : srvModels)
       {
@@ -251,7 +254,7 @@ WorldIter LocalCache::AllWorlds() const
     for (auto &server : this->dataPtr->config->Servers())
     {
       std::string path = common::joinPaths(
-          this->dataPtr->config->CacheLocation(), server.Url().Path().Str());
+          this->dataPtr->config->CacheLocation(), uriToPath(server.Url()));
 
       // Make sure the server info is correct
       auto srvWorlds = this->dataPtr->WorldsInServer(path);
@@ -383,7 +386,7 @@ bool LocalCache::SaveModel(
   std::string cacheLocation = this->dataPtr->config->CacheLocation();
 
   std::string modelRootDir = common::joinPaths(cacheLocation,
-      _id.Server().Url().Path().Str(), _id.Owner(), "models", _id.Name());
+      uriToPath(_id.Server().Url()), _id.Owner(), "models", _id.Name());
   std::string modelVersionedDir =
     common::joinPaths(modelRootDir, _id.VersionStr());
 
@@ -670,6 +673,10 @@ void LocalCachePrivate::FixPathsInMaterialElement(
             workflowElem->FirstChildElement("emissive_map");
         if (emissiveElem)
           this->FixPathsInUri(emissiveElem, _id);
+        tinyxml2::XMLElement *lightElem =
+            workflowElem->FirstChildElement("light_map");
+        if (lightElem)
+          this->FixPathsInUri(lightElem, _id);
         // metal workflow specific elements
         if (workflow == "metal")
         {
