@@ -17,10 +17,11 @@
 
 #include <gtest/gtest.h>
 #include <string>
-#include <gz/common/Console.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/utilities/ExtraTestMacros.hh>
 
-#include "gz/fuel_tools/ClientConfig.hh"
-#include "gz/fuel_tools/ModelIdentifier.hh"
+#include "ignition/fuel_tools/ClientConfig.hh"
+#include "ignition/fuel_tools/ModelIdentifier.hh"
 
 using namespace ignition;
 using namespace fuel_tools;
@@ -55,7 +56,8 @@ TEST(ModelIdentifier, SetFields)
 
 /////////////////////////////////////////////////
 /// \brief Unique Name
-TEST(ModelIdentifier, UniqueName)
+// See https://github.com/gazebosim/gz-fuel-tools/issues/231
+TEST(ModelIdentifier, IGN_UTILS_TEST_DISABLED_ON_WIN32(UniqueName))
 {
   ServerConfig srv1;
   srv1.SetUrl(common::URI("https://localhost:8001/"));
@@ -155,7 +157,7 @@ TEST(ModelIdentifier, AsString)
         "Name: \n"\
         "Owner: \n"\
         "Version: tip\n"\
-        "Unique name: https://fuel.gazebosim.org/models/\n"
+        "Unique name: https://fuel.ignitionrobotics.org/models/\n"
         "Description: \n"
         "File size: 0\n"
         "Upload date: 0\n"
@@ -166,7 +168,7 @@ TEST(ModelIdentifier, AsString)
         "License image URL: \n"
         "Tags: \n"
         "Server:\n"
-        "  URL: https://fuel.gazebosim.org\n"
+        "  URL: https://fuel.ignitionrobotics.org\n"
         "  Version: 1.0\n"
         "  API key: \n";
 #else
@@ -174,7 +176,7 @@ TEST(ModelIdentifier, AsString)
         "Name: \n"\
         "Owner: \n"\
         "Version: tip\n"\
-        "Unique name: https://fuel.gazebosim.org/models\n"
+        "Unique name: https://fuel.ignitionrobotics.org/models\n"
         "Description: \n"
         "File size: 0\n"
         "Upload date: 0\n"
@@ -185,7 +187,7 @@ TEST(ModelIdentifier, AsString)
         "License image URL: \n"
         "Tags: \n"
         "Server:\n"
-        "  URL: https://fuel.gazebosim.org\n"
+        "  URL: https://fuel.ignitionrobotics.org\n"
         "  Version: 1.0\n"
         "  API key: \n";
 #endif
@@ -223,7 +225,7 @@ TEST(ModelIdentifier, AsPrettyString)
     ModelIdentifier id;
     std::string str =
       "\x1B[96m\x1B[1mServer:\x1B[0m\n  "
-      "\x1B[96m\x1B[1mURL: \x1B[0m\x1B[37mhttps://fuel.gazebosim.org"
+      "\x1B[96m\x1B[1mURL: \x1B[0m\x1B[37mhttps://fuel.ignitionrobotics.org"
       "\x1B[0m\n  \x1B[96m\x1B[1mVersion: \x1B[0m\x1B[37m1.0\x1B[0m\n";
     EXPECT_EQ(str, id.AsPrettyString());
   }
