@@ -19,10 +19,11 @@
 #include <cstdio>
 #include <string>
 
-#include "gz/fuel_tools/ClientConfig.hh"
-#include "gz/fuel_tools/ModelIter.hh"
-#include "gz/fuel_tools/ModelIterPrivate.hh"
-#include "gz/fuel_tools/ModelPrivate.hh"
+#include "ignition/fuel_tools/ClientConfig.hh"
+#include "ignition/fuel_tools/ModelIter.hh"
+
+#include "ModelIterPrivate.hh"
+#include "ModelPrivate.hh"
 
 using namespace ignition;
 using namespace fuel_tools;
@@ -45,7 +46,7 @@ namespace ignition
       public: static ModelIter ModelIterThreeModelIds()
         {
           ServerConfig srv;
-          srv.SetUrl(common::URI("https://gazebosim.org"));
+          srv.SetUrl(common::URI("https://ignitionrobotics.org"));
 
           std::vector<ModelIdentifier> ids;
           for (int i = 0; i < 3; i++)
@@ -67,7 +68,7 @@ namespace ignition
       public: static ModelIter ModelIterThreeModels()
         {
           ServerConfig srv;
-          srv.SetUrl(common::URI("https://gazebosim.org"));
+          srv.SetUrl(common::URI("https://ignitionrobotics.org"));
 
           std::vector<Model> models;
           for (int i = 0; i < 3; i++)
