@@ -19,9 +19,10 @@
 #include <cstdio>
 #include <string>
 
-#include "gz/fuel_tools/ClientConfig.hh"
-#include "gz/fuel_tools/WorldIter.hh"
-#include "gz/fuel_tools/WorldIterPrivate.hh"
+#include "ignition/fuel_tools/ClientConfig.hh"
+#include "ignition/fuel_tools/WorldIter.hh"
+
+#include "WorldIterPrivate.hh"
 
 using namespace ignition;
 using namespace fuel_tools;
@@ -44,7 +45,7 @@ namespace ignition
       public: static WorldIter WorldIterThreeWorldIds()
         {
           ServerConfig srv;
-          srv.SetUrl(common::URI("https://gazebosim.org"));
+          srv.SetUrl(common::URI("https://ignitionrobotics.org"));
 
           std::vector<WorldIdentifier> ids;
           for (int i = 0; i < 3; i++)
